@@ -239,14 +239,23 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
         if not lbaas_state:
             lbaas_state = obj_lbaas.LBaaSState()
 
-        prev_service_pub_ip_info = lbaas_state.service_pub_ip_info
         if self._sync_lbaas_members(endpoints, lbaas_state, lbaas_spec):
-            # For LoadBalancer service type, update k8s-service status with
-            # floating IP address if needed.
-            if (prev_service_pub_ip_info != lbaas_state.service_pub_ip_info
-                    and lbaas_state.service_pub_ip_info is not None):
-                self._update_lb_status(
-                    endpoints, lbaas_state.service_pub_ip_info.ip_addr)
+            # Note(yboaron) For LoadBalancer services, we should allocate FIP,
+            # associate it to LB VIP and update K8S service status
+            if lbaas_state.service_pub_ip_info is None:
+                service_pub_ip_info = (
+                    self._drv_service_pub_ip.acquire_service_pub_ip_info(
+                        lbaas_spec.type,
+                        lbaas_spec.lb_ip,
+                        lbaas_spec.project_id,
+                        lbaas_state.loadbalancer.port_id))
+                if service_pub_ip_info:
+                    self._drv_service_pub_ip.associate_pub_ip(
+                        service_pub_ip_info, lbaas_state.loadbalancer.port_id)
+                    lbaas_state.service_pub_ip_info = service_pub_ip_info
+                    self._update_lb_status(
+                        endpoints,
+                        lbaas_state.service_pub_ip_info.ip_addr)
             # REVISIT(ivc): since _sync_lbaas_members is responsible for
             # creating all lbaas components (i.e. load balancer, listeners,
             # pools, members), it is currently possible for it to fail (due
@@ -343,7 +352,8 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                                                              p.port]
             except KeyError:
                 continue
-        current_targets = {(str(m.ip), m.port) for m in lbaas_state.members}
+        current_targets = {(str(m.ip), m.port, m.pool_id)
+                           for m in lbaas_state.members}
 
         for subset in endpoints.get('subsets', []):
             subset_ports = subset.get('ports', [])
@@ -359,10 +369,14 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                     continue
                 for subset_port in subset_ports:
                     target_port = subset_port['port']
-                    if (target_ip, target_port) in current_targets:
-                        continue
                     port_name = subset_port.get('name')
-                    pool = pool_by_tgt_name[port_name]
+                    try:
+                        pool = pool_by_tgt_name[port_name]
+                    except KeyError:
+                        LOG.debug("No pool found for port: %r", port_name)
+                        continue
+                    if (target_ip, target_port, pool.id) in current_targets:
+                        continue
                     # TODO(apuimedo): Do not pass subnet_id at all when in
                     # L3 mode once old neutron-lbaasv2 is not supported, as
                     # octavia does not require it
@@ -574,18 +588,6 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                     ip=lbaas_spec.ip,
                     security_groups_ids=lbaas_spec.security_groups_ids,
                     service_type=lbaas_spec.type)
-                if lbaas_state.service_pub_ip_info is None:
-                    service_pub_ip_info = (
-                        self._drv_service_pub_ip.acquire_service_pub_ip_info(
-                            lbaas_spec.type,
-                            lbaas_spec.lb_ip,
-                            lbaas_spec.project_id))
-                    if service_pub_ip_info:
-                        # if loadbalancerIP should be defined for lbaas,
-                        #  associate it to lbaas VIP
-                        self._drv_service_pub_ip.associate_pub_ip(
-                            service_pub_ip_info, lb.port_id)
-                        lbaas_state.service_pub_ip_info = service_pub_ip_info
                 changed = True
             elif lbaas_state.service_pub_ip_info:
                 self._drv_service_pub_ip.release_pub_ip(
