@@ -157,6 +157,33 @@ class TestFipPubIpDriver(test_base.TestCase):
         retcode = cls.associate(m_driver, res_id, vip_port_id)
         self.assertIsNone(retcode)
 
+    def test_associate_conflict_correct(self):
+        driver = d_public_ip.FipPubIpDriver()
+        res_id = mock.sentinel.res_id
+        vip_port_id = mock.sentinel.vip_port_id
+
+        neutron = self.useFixture(k_fix.MockNeutronClient()).client
+        neutron.update_floatingip.side_effect = n_exc.Conflict
+        neutron.show_floatingip.return_value = {
+            'floatingip': {
+                'id': res_id,
+                'port_id': vip_port_id}}
+        self.assertIsNone(driver.associate(res_id, vip_port_id))
+
+    def test_associate_conflict_incorrect(self):
+        driver = d_public_ip.FipPubIpDriver()
+        res_id = mock.sentinel.res_id
+        vip_port_id = mock.sentinel.vip_port_id
+
+        neutron = self.useFixture(k_fix.MockNeutronClient()).client
+        neutron.update_floatingip.side_effect = n_exc.Conflict
+        neutron.show_floatingip.return_value = {
+            'floatingip': {
+                'id': res_id,
+                'port_id': 'foo'}}
+        self.assertRaises(n_exc.Conflict, driver.associate, res_id,
+                          vip_port_id)
+
     def test_associate_succeeded(self):
         cls = d_public_ip.FipPubIpDriver
         m_driver = mock.Mock(spec=cls)
