@@ -468,15 +468,27 @@ class TestLoadBalancerHandler(test_base.TestCase):
 
     def test_on_present(self):
         lbaas_spec = mock.sentinel.lbaas_spec
+        lbaas_spec.type = 'DummyType'
+        lbaas_spec.lb_ip = "1.2.3.4"
+        lbaas_spec.project_id = 12345678
+
         lbaas_state = mock.sentinel.lbaas_state
         lbaas_state.service_pub_ip_info = None
+        loadbalancer = mock.Mock()
+        loadbalancer.port_id = 12345678
+        lbaas_state.loadbalancer = loadbalancer
         endpoints = mock.sentinel.endpoints
 
+        m_drv_service_pub_ip = mock.Mock()
+        m_drv_service_pub_ip.acquire_service_pub_ip_info.return_value = None
+        m_drv_service_pub_ip.associate_pub_ip.return_value = True
+
         m_handler = mock.Mock(spec=h_lbaas.LoadBalancerHandler)
         m_handler._get_lbaas_spec.return_value = lbaas_spec
         m_handler._should_ignore.return_value = False
         m_handler._get_lbaas_state.return_value = lbaas_state
         m_handler._sync_lbaas_members.return_value = True
+        m_handler._drv_service_pub_ip = m_drv_service_pub_ip
 
         h_lbaas.LoadBalancerHandler.on_present(m_handler, endpoints)
 
@@ -490,6 +502,22 @@ class TestLoadBalancerHandler(test_base.TestCase):
         m_handler._update_lb_status.assert_not_called()
 
     def _fake_sync_lbaas_members(self, endpoints, lbaas_state, lbaas_spec):
+        loadbalancer = mock.Mock()
+        loadbalancer.port_id = 12345678
+        lbaas_state.loadbalancer = loadbalancer
+        lbaas_state.service_pub_ip_info = None
+        return True
+
+    def test_on_present_loadbalancer_service(self):
+        lbaas_spec = mock.sentinel.lbaas_spec
+        lbaas_spec.type = 'LoadBalancer'
+        lbaas_spec.lb_ip = "1.2.3.4"
+        lbaas_spec.project_id = 12345678
+
+        lbaas_state = mock.sentinel.lbaas_state
+        lbaas_state.service_pub_ip_info = None
+        endpoints = mock.sentinel.endpoints
+
         floating_ip = {'floating_ip_address': '1.2.3.5',
                        'id': 'ec29d641-fec4-4f67-928a-124a76b3a888'}
 
@@ -497,20 +525,17 @@ class TestLoadBalancerHandler(test_base.TestCase):
             ip_id=floating_ip['id'],
             ip_addr=floating_ip['floating_ip_address'], alloc_method='kk')
 
-        lbaas_state.service_pub_ip_info = service_pub_ip_info
-        return True
-
-    def test_on_present_loadbalancer_service(self):
-        lbaas_spec = mock.sentinel.lbaas_spec
-        lbaas_state = mock.sentinel.lbaas_state
-        lbaas_state.service_pub_ip_info = None
-        endpoints = mock.sentinel.endpoints
+        m_drv_service_pub_ip = mock.Mock()
+        m_drv_service_pub_ip.acquire_service_pub_ip_info.return_value = (
+            service_pub_ip_info)
+        m_drv_service_pub_ip.associate_pub_ip.return_value = True
 
         m_handler = mock.Mock(spec=h_lbaas.LoadBalancerHandler)
         m_handler._get_lbaas_spec.return_value = lbaas_spec
         m_handler._should_ignore.return_value = False
         m_handler._get_lbaas_state.return_value = lbaas_state
         m_handler._sync_lbaas_members = self._fake_sync_lbaas_members
+        m_handler._drv_service_pub_ip = m_drv_service_pub_ip
 
         h_lbaas.LoadBalancerHandler.on_present(m_handler, endpoints)
 
@@ -523,8 +548,18 @@ class TestLoadBalancerHandler(test_base.TestCase):
 
     def test_on_present_rollback(self):
         lbaas_spec = mock.sentinel.lbaas_spec
+        lbaas_spec.type = 'ClusterIp'
+        lbaas_spec.lb_ip = '1.2.3.4'
+        lbaas_spec.project_id = '12345678'
         lbaas_state = mock.sentinel.lbaas_state
         lbaas_state.service_pub_ip_info = None
+        loadbalancer = mock.Mock()
+        loadbalancer.port_id = 12345678
+        lbaas_state.loadbalancer = loadbalancer
+        m_drv_service_pub_ip = mock.Mock()
+        m_drv_service_pub_ip.acquire_service_pub_ip_info.return_value = None
+        m_drv_service_pub_ip.associate_pub_ip.return_value = True
+
         endpoints = mock.sentinel.endpoints
 
         m_handler = mock.Mock(spec=h_lbaas.LoadBalancerHandler)
@@ -534,7 +569,7 @@ class TestLoadBalancerHandler(test_base.TestCase):
         m_handler._sync_lbaas_members.return_value = True
         m_handler._set_lbaas_state.side_effect = (
             k_exc.K8sResourceNotFound('ep'))
-
+        m_handler._drv_service_pub_ip = m_drv_service_pub_ip
         h_lbaas.LoadBalancerHandler.on_present(m_handler, endpoints)
 
         m_handler._get_lbaas_spec.assert_called_once_with(endpoints)
@@ -870,3 +905,45 @@ class TestLoadBalancerHandler(test_base.TestCase):
     def test_set_lbaas_state(self):
         self.skipTest("skipping until generalised annotation handling is "
                       "implemented")
+
+    @mock.patch('kuryr_kubernetes.controller.drivers.base'
+                '.PodSubnetsDriver.get_instance')
+    @mock.patch('kuryr_kubernetes.controller.drivers.base'
+                '.PodProjectDriver.get_instance')
+    @mock.patch('kuryr_kubernetes.controller.drivers.base'
+                '.LBaaSDriver.get_instance')
+    def test_add_new_members_udp(self, m_get_drv_lbaas,
+                                 m_get_drv_project, m_get_drv_subnets):
+        project_id = str(uuidutils.generate_uuid())
+        subnet_id = str(uuidutils.generate_uuid())
+        current_ip = '1.1.1.1'
+        current_targets = {
+            '1.1.1.101': (1001, 10001),
+            '1.1.1.111': (1001, 10001),
+            '1.1.1.201': (2001, 20001)}
+        expected_ip = '2.2.2.2'
+        expected_targets = {
+            '2.2.2.101': (1201, 12001),
+            '2.2.2.111': (1201, 12001),
+            '2.2.2.201': (2201, 22001)}
+        endpoints = self._generate_endpoints(expected_targets)
+        state = self._generate_lbaas_state(
+            current_ip, current_targets, project_id, subnet_id)
+        spec = self._generate_lbaas_spec(expected_ip, expected_targets,
+                                         project_id, subnet_id, 'UDP')
+
+        m_drv_lbaas = mock.Mock(wraps=FakeLBaaSDriver())
+        m_drv_project = mock.Mock()
+        m_drv_project.get_project.return_value = project_id
+        m_drv_subnets = mock.Mock()
+        m_drv_subnets.get_subnets.return_value = {
+            subnet_id: mock.sentinel.subnet}
+        m_get_drv_lbaas.return_value = m_drv_lbaas
+        m_get_drv_project.return_value = m_drv_project
+        m_get_drv_subnets.return_value = m_drv_subnets
+
+        handler = h_lbaas.LoadBalancerHandler()
+        member_added = handler._add_new_members(endpoints, state, spec)
+
+        self.assertEqual(member_added, False)
+        m_drv_lbaas.ensure_member.assert_not_called()
